package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.communityNews.CommentStars;

import java.util.List;

/**
 * 社区资讯收藏Mapper接口
 * 
 * @author boman
 * @date 2025-02-25
 */
public interface CommentStarsMapper 
{
    /**
     * 查询社区资讯收藏
     * 
     * @param starsId 社区资讯收藏主键
     * @return 社区资讯收藏
     */
    public CommentStars selectCommentStarsByStarsId(Long starsId);

    /**
     * 查询社区资讯收藏列表
     * 
     * @param commentStars 社区资讯收藏
     * @return 社区资讯收藏集合
     */
    public List<CommentStars> selectCommentStarsList(CommentStars commentStars);

    /**
     * 新增社区资讯收藏
     * 
     * @param commentStars 社区资讯收藏
     * @return 结果
     */
    public int insertCommentStars(CommentStars commentStars);

    /**
     * 修改社区资讯收藏
     * 
     * @param commentStars 社区资讯收藏
     * @return 结果
     */
    public int updateCommentStars(CommentStars commentStars);

    /**
     * 根据用户id和资讯id更新收藏状态 没删除就已收藏 删除=未收藏
     * @param commentStars
     * @return
     */
    public int updateCommentStarsByUserIdAndCommunityId(CommentStars commentStars);

    /**
     * 删除社区资讯收藏
     * 
     * @param starsId 社区资讯收藏主键
     * @return 结果
     */
    public int deleteCommentStarsByStarsId(Long starsId);

    /**
     * 批量删除社区资讯收藏
     * 
     * @param starsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCommentStarsByStarsIds(Long[] starsIds);
    public int deleteCommentStarsByCommunityIds(Long[] communityIds);
}
